import metview as mv #for reading and plotting grib files
import numpy as np #for grid/data manipulation
import matplotlib.pyplot as plt #For plotting figures

SM =mv.read("h14_2019053000.grib") #Read in grib data for 30/5/2019:

SWI1=mv.read(data=SM,param="40.228") #1st layer (0-7 cm depth)
SWI2=mv.read(data=SM,param="41.228") #2nd layer (7-28 cm depth)
SWI3=mv.read(data=SM,param="42.228") #3rd layer (28-100 cm depth)
SWI4=mv.read(data=SM,param="43.228") #4th layer (100-289 cm)
qc=mv.read(data=SM,param="200.228") #Quality control flag (1=normal, 2=risk of frozen conditions, 
#3=outside nominal range)

RZSM = SWI1 
#Extract root-zone SM values from depth integrating the 4 layers
RZSM = RZSM.set_values(SWI1.values()*0.07 + SWI2.values()*0.21 + SWI3.values()*0.72)

#Mask suspect data
masked_data=RZSM.values(); np.warnings.filterwarnings('ignore'); masked_data[qc.values()>1.0]=np.nan
RZSM = RZSM.set_values(masked_data)

#Create contouring for metview plot
cont_pc = mv.mcont(contour = "off",  
          legend = "on",
          contour_shade = "on",
          contour_level_selection_type = "level_list",
          contour_level_list = [0.0, 0.125, 0.25, 0.375, 0.5, 0.625, 0.75, 0.875, 1.0],
          contour_label_format = "(F4.1)",
          contour_label = "off",
          contour_label_height = 0.40,
          contour_label_colour = "charcoal",
          contour_label_frequency = 10,
          contour_highlight              = "off",
          contour_shade_method = "area_fill",
          contour_shade_colour_method = "gradients",
          contour_gradients_colour_list = ['burgundy','red','orange','yellow','green','cyan','sky','blue','navy'],
          contour_gradients_step_list = [20,20,20,20,20,20,20,20])

#Create legend:
my_legend = mv.mlegend(legend_display_type = "continuous",
                 legend_entry_border='off',
                 legend_text_colour = "charcoal",
                 legend_values_list= [0.0, 0.2, 0.4, 0.6, 0.8, 1.0],
                 legend_text_composition = 'user_text_only',
                 legend_text_font_size = 1,
                 legend_user_maximum = "on",
)

# shaded land to make the points stand out more
grey_land_shading = mv.mcoast(
    map_coastline_land_shade        = "on",
    map_coastline_land_shade_colour = "grey",
    map_grid_latitude_increment     = 40,
    map_grid_longitude_increment    = 80,
    map_grid_colour                 = "charcoal",
    map_grid = "off",
    map_label = "off")

#Extract global domain [upper lon, lower lon, upper lat, lower lat]
area_view = mv.geoview(
    map_area_definition = 'corners',
    area = [-89,-179,89,179],
    coastlines = grey_land_shading
)

#Create title
title = mv.mtext(text_lines = ["<font size='1'>H14 root-zone SWI</font>",""],
          text_justification = "centre",
          text_font_size = 0.5,
          text_colour = "charcoal")

#Create plot
mv.setoutput(mv.png_output(output_name = 'H14_SWI_20190530')) # To save as png image
dw = mv.plot_superpage(pages = mv.mvl_regular_layout(area_view,1,1,1,1))
mv.plot(dw[0], RZSM, cont_pc, my_legend,title)
